==> google-cloud-sdk-163.0.0.tgz: google-cloud-sdk/lib/surface/compute/backend_buckets/describe.py <==
# Copyright 2015 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for describing backend buckets."""
from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute import flags as compute_flags
from googlecloudsdk.command_lib.compute.backend_buckets import flags


class Describe(base.DescribeCommand):
  """Describe a backend bucket.

  *{command}* displays all data associated with a backend bucket in a
  project.
  """

  BACKEND_BUCKET_ARG = None

  @staticmethod
  def Args(parser):
    Describe.BACKEND_BUCKET_ARG = flags.BackendBucketArgument()
    Describe.BACKEND_BUCKET_ARG.AddArgument(parser, operation_type='describe')

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    client = holder.client

    backend_bucket_ref = Describe.BACKEND_BUCKET_ARG.ResolveAsResource(
        args,
        holder.resources,
        scope_lister=compute_flags.GetDefaultScopeLister(client))

    request = client.messages.ComputeBackendBucketsGetRequest(
        **backend_bucket_ref.AsDict())

    return client.MakeRequests([(client.apitools_client.backendBuckets,
                                 'Get', request)])[0]

==> google-cloud-sdk-218.0.0.tgz: google-cloud-sdk/lib/surface/compute/backend_buckets/describe.py <==
# -*- coding: utf-8 -*- #
# Copyright 2015 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for describing backend buckets."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute import flags as compute_flags
from googlecloudsdk.command_lib.compute.backend_buckets import flags


class Describe(base.DescribeCommand):
  """Describe a backend bucket.

  *{command}* displays all data associated with a backend bucket in a
  project.
  """

  BACKEND_BUCKET_ARG = None

  @staticmethod
  def Args(parser):
    Describe.BACKEND_BUCKET_ARG = flags.BackendBucketArgument()
    Describe.BACKEND_BUCKET_ARG.AddArgument(parser, operation_type='describe')

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    client = holder.client

    backend_bucket_ref = Describe.BACKEND_BUCKET_ARG.ResolveAsResource(
        args,
        holder.resources,
        scope_lister=compute_flags.GetDefaultScopeLister(client))

    request = client.messages.ComputeBackendBucketsGetRequest(
        **backend_bucket_ref.AsDict())

    return client.MakeRequests([(client.apitools_client.backendBuckets,
                                 'Get', request)])[0]
